@@ -8,7 +8,7 @@ from email.generator import Generator
 from functools import lru_cache
 from operator import attrgetter, itemgetter
 from pathlib import Path
-from typing import Dict, List, Literal, Optional, Tuple, Union
+from typing import Dict, List, Literal, Optional, Set, Tuple, Union
 
 import semver
 from pbt.config import PBTConfig
@@ -100,6 +100,8 @@ class PkgManager(ABC):
     ):
         """Install the given dependency for the given package.
 
+        The dependency must not be the phantom package as it does not containing any code to build or install.
+
         Note: don't expect this function will be able to find the local dependencies in the project
         as the manager relies on a package registry. For local dependencies, add them to `skip_deps` anddd use `install_dependency` to install them
         separately instead. Otherwise, you may get an error.
@@ -121,7 +123,7 @@ class PkgManager(ABC):
         skip_deps: List[str] = None,
         additional_deps: Dict[str, DepConstraints] = None,
     ):
-        """Install the package, assuming the the specification is updated.
+        """Install the package, assuming the the specification is updated. Note that if the package is phantom, only the dependencies are installed.
 
         Note: don't expect this function will be able to find the local dependencies in the project
         as the manager relies on a package registry. For local dependencies, add them to `skip_deps` anddd use `install_dependency` to install them
@@ -145,6 +147,11 @@ class PkgManager(ABC):
         """
         raise NotImplementedError()
 
+    @abstractmethod
+    def get_fixed_version_pkgs(self) -> Set[str]:
+        """Get set of packages which versions are fixed and never should updated."""
+        raise NotImplementedError()
+
     def filter_included_files(self, pkg: Package, files: List[str]) -> List[str]:
         """Filter out the files that are not included in the package, these are files that
         won't affect the content of the package.
