@@ -11,7 +11,7 @@ from loguru import logger
 from pytest import skip
 from pbt.config import PBTConfig
 from pbt.diff import Diff, diff_db
-from pbt.misc import cache_func, exec
+from pbt.misc import ExecProcessError, cache_func, exec
 from pbt.package.manager.manager import PkgManager, build_cache
 from pbt.package.package import DepConstraint, DepConstraints, Package, PackageType
 from tomlkit.api import document, dumps, inline_table, loads, nl, table
@@ -22,6 +22,7 @@ class Poetry(PkgManager):
     def __init__(self, cfg: PBTConfig) -> None:
         super().__init__()
         self.cfg = cfg
+        self.fixed_version_pkgs = {"python"}
 
     def is_package_directory(self, dir: Path) -> bool:
         return (dir / "pyproject.toml").exists()
@@ -232,10 +233,9 @@ class Poetry(PkgManager):
         shutil.rmtree(pkg.location / "dist", ignore_errors=True)
 
     def publish(self, pkg: Package):
+        # exec("poetry publish --build", cwd=pkg.location, **self.exec_options("publish"))
         raise NotImplementedError()
 
-    #     exec("poetry publish --build", cwd=pkg.location, **self.exec_options("publish"))
-
     def install(
         self,
         pkg: Package,
@@ -249,13 +249,29 @@ class Poetry(PkgManager):
         options = "--no-dev" if not include_dev else ""
 
         with self.mask(pkg, skip_deps, additional_deps):
-            exec(
-                f"poetry install {options}",
-                cwd=pkg.location,
-                **self.exec_options("install"),
-            )
+            try:
+                exec(
+                    f"poetry install {options}",
+                    cwd=pkg.location,
+                    **self.exec_options("install"),
+                )
+            except ExecProcessError as e:
+                if str(e).find(
+                    "Warning: The lock file is not up to date with the latest changes in pyproject.toml. You may be getting outdated dependencies. Run update to update them."
+                ):
+                    # try to update the lock file without upgrade previous packages, and retry
+                    exec(
+                        "poetry lock --no-update",
+                        cwd=pkg.location,
+                        **self.exec_options("install"),
+                    )
+                    exec(
+                        f"poetry install {options}",
+                        cwd=pkg.location,
+                        **self.exec_options("install"),
+                    )
 
-        if editable:
+        if editable and pkg.name not in self.cfg.phantom_packages:
             self.build_editable(pkg, skip_deps=skip_deps)
             exec([self.python_path(pkg), "setup.py", "develop"], cwd=pkg.location)
             (pkg.location / "setup.py").unlink()  # remove the setup.py file
@@ -325,6 +341,9 @@ class Poetry(PkgManager):
                 assert memberfile is not None
                 f.write(memberfile.read())
 
+    def get_fixed_version_pkgs(self):
+        return self.fixed_version_pkgs
+
     def compute_pkg_hash(self, pkg: Package) -> str:
         """Compute hash of the content of the package"""
         self.build(pkg)
@@ -342,6 +361,7 @@ class Poetry(PkgManager):
         editable: bool = False,
         skip_dep_deps: List[str] = None,
     ):
+        assert dependency.name not in self.cfg.phantom_packages, dependency.name
         skip_dep_deps = skip_dep_deps or []
         exec([self.pip_path(pkg), "uninstall", "-y", dependency.name])
 
