@@ -31,6 +31,12 @@ class BTPipeline:
         """Discover packages in the project."""
         pkgs = {}
         for manager in self.managers.values():
+            if manager.is_package_directory(self.root):
+                pkg = manager.load(self.root)
+                if pkg.name in pkgs:
+                    raise RuntimeError(f"Duplicate package {pkg.name}")
+                pkgs[pkg.name] = pkg
+
             for fpath in glob.glob(manager.glob_query(self.root)):
                 pkg = manager.load(Path(fpath).parent)
                 if pkg.name in pkgs:
@@ -69,6 +75,10 @@ class BTPipeline:
             is_modified = False
             for deps in [pkg.dependencies, pkg.dev_dependencies]:
                 for dep, specs in deps.items():
+                    if dep in manager.get_fixed_version_pkgs():
+                        # skip fixed version packages
+                        continue
+
                     if dep in self.pkgs:
                         # update your own packages
                         dep_version = manager.parse_version(self.pkgs[dep].version)
@@ -145,7 +155,12 @@ class BTPipeline:
 
                 for dep in deps:
                     if isinstance(dep, Package):
-                        manager.install_dependency(pkg, dep, editable=editable)
+                        skip_dep_deps = list(dep.dependencies.keys()) + list(
+                            dep.dev_dependencies.keys()
+                        )
+                        manager.install_dependency(
+                            pkg, dep, editable=editable, skip_dep_deps=skip_dep_deps
+                        )
 
     def publish(self, pkg_names: List[str], registries: Dict[PackageType, PkgRegistry]):
         """Publish a package. Check if the package is modified but the version is not changed so
